@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -55,6 +55,31 @@ if (read_config_option('auth_method') == '2') {
 		$upart = explode('@', $username);
 		$username = $upart[0];
 	}
+
+	/* Handle mapping basic accounts to shortform accounts.
+	 * Fromat of map file is CSV: basic,shortform */
+	$mapfile = read_config_option('path_basic_mapfile');
+	if ($mapfile != '' && file_exists($mapfile) && is_readable($mapfile)) {
+		$records = file($mapfile);
+		$found   = false;
+
+		if (sizeof($records)) {
+			foreach($records as $r) {
+				list($basic, $shortform) = str_getcsv($r);
+
+				if (trim($basic) == $username) {
+					$username = trim($shortform);
+					$found    = true;
+
+					break;
+				}
+			}
+		}
+
+		if (!$found) {
+			cacti_log("WARNING: Username $username not found in basic mapfile.", false, 'AUTH');
+		}
+	}
 } else {
 	if (get_nfilter_request_var('action') == 'login') {
 		/* LDAP and Builtin get username from Form */
@@ -162,9 +187,14 @@ if (get_nfilter_request_var('action') == 'login') {
 					$ldap_error = true;
 					$ldap_error_message = __('LDAP Error: %s', $ldap_auth_response['error_text']);
 					$user_auth = false;
+
+					$id = db_fetch_cell_prepared('SELECT id
+						FROM user_auth
+						WHERE username = ?
+						AND realm = 3',
+						array($username));
 				}
 			}
-
 		}
 
 		break;
@@ -191,18 +221,20 @@ if (get_nfilter_request_var('action') == 'login') {
 			if ((!$user_auth)) {
 				$stored_pass = db_fetch_cell_prepared('SELECT password
 					FROM user_auth
-					WHERE username = ? AND realm = 0',
+					WHERE username = ?
+					AND realm = 0',
 					array($username));
 
 				if ($stored_pass != '') {
 					$p = get_nfilter_request_var('login_password');
 					$valid = compat_password_verify($p, $stored_pass);
 
-					cacti_log("DEBUG: User '" . $username . "' password is " . ($valid?'':'in') . "valid", false, 'AUTH', POLLER_VERBOSITY_DEBUG);
+					cacti_log("DEBUG: User '" . $username . "' password is " . ($valid?'':'in') . 'valid', false, 'AUTH', POLLER_VERBOSITY_DEBUG);
 					if ($valid) {
 						$user = db_fetch_row_prepared('SELECT *
 							FROM user_auth
-							WHERE username = ? AND realm = 0',
+							WHERE username = ?
+							AND realm = 0',
 							array($username));
 
 						if (compat_password_needs_rehash($stored_pass, PASSWORD_DEFAULT)) {
@@ -218,7 +250,6 @@ if (get_nfilter_request_var('action') == 'login') {
 			}
 		}
 	}
-	/* end of switch */
 
 	/* Create user from template if requested */
 	if (!cacti_sizeof($user) && $copy_user && get_template_account() != '0' && $username != '') {
@@ -236,7 +267,7 @@ if (get_nfilter_request_var('action') == 'login') {
 			$cn_email     = read_config_option('cn_email');
 
 			if ($cn_full_name != '' || $cn_email != '') {
-				$ldap_cn_search_response = cacti_ldap_search_cn($username, array($cn_full_name,$cn_email));
+				$ldap_cn_search_response = cacti_ldap_search_cn($username, array($cn_full_name, $cn_email));
 
    				if (isset($ldap_cn_search_response['cn'])) {
 					$data_override = array();
@@ -281,9 +312,9 @@ if (get_nfilter_request_var('action') == 'login') {
 
 	/* Guest account checking - Not for builtin */
 	$guest_user = false;
-	if ((!cacti_sizeof($user)) && ($user_auth) && (get_guest_account() != '0')) {
+	if (!cacti_sizeof($user) && $user_auth && get_guest_account() != '0') {
 		/* Locate guest user record */
-		$user = db_fetch_row_prepared('SELECT id, username, enabled
+		$user = db_fetch_row_prepared('SELECT *
 			FROM user_auth
 			WHERE id = ?',
 			array(get_guest_account()));
@@ -313,7 +344,12 @@ if (get_nfilter_request_var('action') == 'login') {
 			array($username, $user['id'], $client_addr));
 
 		/* is user enabled */
-		$user_enabled = $user['enabled'];
+		if (isset($user['enabled'])) {
+			$user_enabled = $user['enabled'];
+		} else {
+			$user_enabled = 'on';
+		}
+
 		if ($user_enabled != 'on') {
 			/* Display error */
 			display_custom_error_message(__('Access Denied, user account disabled.'));
@@ -330,10 +366,7 @@ if (get_nfilter_request_var('action') == 'login') {
 		$_SESSION['sess_user_id'] = $user['id'];
 
 		/* handle 'force change password' */
-		if (($user['must_change_password'] == 'on') &&
-			(read_config_option('auth_method') == 1) &&
-			($user['password_change'] == 'on')) {
-
+		if ($user['must_change_password'] == 'on' && read_config_option('auth_method') == 1 && $user['password_change'] == 'on') {
 			$_SESSION['sess_change_password'] = true;
 		}
 
@@ -342,9 +375,11 @@ if (get_nfilter_request_var('action') == 'login') {
 				FROM user_auth_group AS uag
 				INNER JOIN user_auth_group_members AS uagm
 				ON uag.id=uagm.group_id
-				WHERE user_id=?', array($_SESSION['sess_user_id']));
+				WHERE user_id = ?
+				AND login_opts != 4',
+				array($_SESSION['sess_user_id']));
 
-			if ($group_options > 0) {
+			if (!empty($group_options)) {
 				$user['login_opts'] = $group_options;
 			}
 		}
@@ -409,21 +444,34 @@ if (get_nfilter_request_var('action') == 'login') {
 			default:
 				api_plugin_hook_function('login_options_navigate', $user['login_opts']);
 		}
+
+		exit;
+	} elseif (!$guest_user && $user_auth) {
+		/* No guest account defined */
+		display_custom_error_message(__('Access Denied, please contact you Cacti Administrator.'));
+		cacti_log('LOGIN: Access Denied, No guest enabled or template user to copy', false, 'AUTH');
+		header('Location: index.php');
 		exit;
 	} else {
-		if ((!$guest_user) && ($user_auth)) {
-			/* No guest account defined */
-			display_custom_error_message(__('Access Denied, please contact you Cacti Administrator.'));
-			cacti_log('LOGIN: Access Denied, No guest enabled or template user to copy', false, 'AUTH');
-			header('Location: index.php');
-			exit;
+		if ($auth_method == 1) {
+			$realm = 0;
 		} else {
-			/* BAD username/password builtin and LDAP */
-			db_execute_prepared('INSERT IGNORE INTO user_log
-				(username, user_id, result, ip, time)
-				VALUES (?, 0, 0, ?, NOW())',
-				array($username, get_client_addr('')));
+			$realm = 3;
 		}
+
+		$id = db_fetch_cell_prepared('SELECT id
+			FROM user_auth
+			WHERE username = ?
+			AND realm = ?',
+			array($username, $realm));
+
+		/* BAD username/password builtin and LDAP */
+		db_execute_prepared('INSERT IGNORE INTO user_log
+			(username, user_id, result, ip, time)
+			VALUES (?, ?, 0, ?, NOW())',
+			array($username, !empty($id) ? $id:0, get_client_addr('')));
+
+		cacti_log('LOGIN: ' . ($realm == 0 ? 'Local':'LDAP') . " Login Failed for user '" . $username . "' from IP Address '" . get_client_addr('') . "'.", false, 'AUTH');
 	}
 }
 
@@ -435,17 +483,17 @@ function auth_display_custom_error_message($message) {
 	global $config;
 
 	/* kill the session */
-	setcookie(session_name(), '', time() - 3600, $config['url_path']);
+	cacti_cookie_logout();
 
 	/* print error */
 	print '<!DOCTYPE html>';
-	print "<html>\n";
-	print "<head>\n";
+	print '<html>';
+	print '<head>';
 	html_common_header(__('Cacti'));
-	print "</head>\n";
-	print "<body>\n<br><br>\n";
-	print $message . "\n";
-	print "</body>\n</html>\n";
+	print '</head>';
+	print '<body><br><br>';
+	print $message;
+	print '</body></html>';
 }
 
 function domains_login_process() {
@@ -509,7 +557,7 @@ function domains_login_process() {
 					$user_template = db_fetch_row_prepared('SELECT *
 						FROM user_auth
 						WHERE id = ?',
-						array(get_template_account()));
+						array($template_user));
 
 					if (!empty($user_template['id']) && $user_template['id'] > 0) {
 						/* template user found */
@@ -581,7 +629,8 @@ function domains_ldap_auth($username, $password = '', $dn = '', $realm) {
 
 	if (!empty($username)) $ldap->username = $username;
 	if (!empty($password)) $ldap->password = $password;
-	if (!empty($dn))       $ldap->dn       = $dn;
+
+	$ldap->dn = $dn;
 
 	$ld = db_fetch_row_prepared('SELECT *
 		FROM user_domains_ldap
@@ -589,7 +638,10 @@ function domains_ldap_auth($username, $password = '', $dn = '', $realm) {
 		array($realm-1000));
 
 	if (cacti_sizeof($ld)) {
-		if (!empty($ld['dn']))                $ldap->dn                = $ld['dn'];
+		if (empty($dn) && !empty($ld['dn'])) {
+			$ldap->dn = $ld['dn'];
+		}
+
 		if (!empty($ld['server']))            $ldap->host              = $ld['server'];
 		if (!empty($ld['port']))              $ldap->port              = $ld['port'];
 		if (!empty($ld['port_ssl']))          $ldap->port_ssl          = $ld['port_ssl'];
@@ -739,7 +791,7 @@ $selectedTheme = get_selected_theme();
 								<label for='realm'><?php print __('Realm');?></label>
 							</td>
 							<td>
-								<select id='realm' name='realm'><?php
+								<select id='realm' name='realm' class='ui-state-default ui-corner-all'><?php
 									if (cacti_sizeof($realms)) {
 										foreach($realms as $index => $realm) {
 											print "\t\t\t\t\t<option value='" . $index . "'" . ($realm['selected'] ? ' selected="selected"':'') . '>' . html_escape($realm['name']) . "</option>\n";
@@ -785,7 +837,38 @@ $selectedTheme = get_selected_theme();
 	</div>
 	<div class='loginRight'></div>
 	<script type='text/javascript'>
+	var storage = Storages.localStorage;
+
 	$(function() {
+		if (storage.isSet('user_realm')) {
+			var preferredRealm = storage.get('user_realm');
+		} else {
+			var preferredRealm = null;
+		}
+
+		if (preferredRealm == null) {
+			preferredRealm = $('#realm option:selected').val();
+		}
+
+		// Restore the preferred realm
+		if ($('#realm').length) {
+			if (preferredRealm !== null) {
+				$('#realm').val(preferredRealm);
+				if ($('#realm').selectmenu('instance') !== undefined) {
+					$('#realm').selectmenu('refresh');
+				}
+			}
+		}
+
+		// Control submit in order to store preferred realm
+		$('#login').submit(function(event) {
+			event.preventDefault();
+			if ($('#realm').length) {
+				storage.set('user_realm', $('#realm').val());
+			}
+			$('#login').off('submit').trigger('submit');
+		});
+
 		$('body').css('height', $(window).height());
 		$('.loginLeft').css('width',parseInt($(window).width()*0.33)+'px');
 		$('.loginRight').css('width',parseInt($(window).width()*0.33)+'px');
