@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -647,7 +647,7 @@ function data_query_item_edit() {
 		array(get_request_var('snmp_query_id')));
 
 	if (cacti_sizeof($snmp_query)) {
-		$header_label = __('Associated Graph/Data Templates [edit: %s]', html_escape($snmp_query['name']));
+		$header_label = __esc('Associated Graph/Data Templates [edit: %s]', $snmp_query['name']);
 	} else {
 		$header_label = __('Associated Graph/Data Templates [new]');
 	}
@@ -1097,7 +1097,7 @@ function data_query_edit() {
 
 	if (!isempty_request_var('id')) {
 		$snmp_query = db_fetch_row_prepared('SELECT * FROM snmp_query WHERE id = ?', array(get_request_var('id')));
-		$header_label = __('Data Queries [edit: %s]', html_escape($snmp_query['name']));
+		$header_label = __esc('Data Queries [edit: %s]', $snmp_query['name']);
 	} else {
 		$header_label = __('Data Queries [new]');
 	}
@@ -1405,7 +1405,7 @@ function data_query() {
 		),
 		'data_input_method' => array(
 			'display' => __('Data Input Method'),
-			'align' => 'left',
+			'align' => 'right',
 			'sort' => 'ASC',
 			'tip' => __('The Data Input Method used to collect data for Data Sources associated with this Data Query.')
 		)
@@ -1436,7 +1436,7 @@ function data_query() {
 			form_selectable_cell($disabled ? __('No'):__('Yes'), $snmp_query['id'], '', 'right');
 			form_selectable_cell(number_format_i18n($snmp_query['graphs'], '-1'), $snmp_query['id'], '', 'right');
 			form_selectable_cell(number_format_i18n($snmp_query['templates'], '-1'), $snmp_query['id'], '', 'right');
-			form_selectable_cell(filter_value($snmp_query['data_input_method'], get_request_var('filter')), $snmp_query['id']);
+			form_selectable_cell(filter_value($snmp_query['data_input_method'], get_request_var('filter')), $snmp_query['id'], '', 'right');
 			form_checkbox_cell($snmp_query['name'], $snmp_query['id'], $disabled);
 			form_end_row();
 		}
