@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -28,7 +28,7 @@ include_once('./lib/utility.php');
 
 $profile_actions = array(
 	1 => __('Delete'),
-//	2 => __('Duplicate')
+	2 => __('Duplicate')
 );
 
 /* set default action */
@@ -74,13 +74,9 @@ switch (get_request_var('action')) {
 
 		break;
 	case 'ajax_size':
-		if (is_numeric(get_nfilter_request_var('rows'))) {
-			get_filter_request_var('id');
-			get_filter_request_var('cfs');
-			print get_size(get_request_var('id'), get_nfilter_request_var('type'), get_request_var('cfs'));
-		} else {
-			print __('N/A');
-		}
+		get_filter_request_var('id');
+		get_filter_request_var('cfs');
+		print get_size(get_request_var('id'), get_nfilter_request_var('type'), get_request_var('cfs'));
 
 		break;
 	case 'item_edit':
@@ -245,9 +241,7 @@ function form_actions() {
 				db_execute('DELETE FROM data_source_profiles_rra WHERE ' . array_to_sql_or($selected_items, 'data_source_profile_id'));
 				db_execute('DELETE FROM data_source_profiles_cf WHERE ' . array_to_sql_or($selected_items, 'data_source_profile_id'));
 			} elseif (get_request_var('drp_action') == '2') { // duplicate
-				for ($i=0;($i<cacti_count($selected_items));$i++) {
-					duplicate_data_source_profile($selected_items[$i], get_nfilter_request_var('title_format'));
-				}
+				duplicate_data_source_profile($selected_items, get_nfilter_request_var('title_format'));
 			}
 		}
 
@@ -276,7 +270,7 @@ function form_actions() {
 
 	form_start('data_source_profiles.php');
 
-	html_start_box($profile_actions{get_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($profile_actions[get_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($profile_array) && cacti_sizeof($profile_array)) {
 		if (get_request_var('drp_action') == '1') { // delete
@@ -325,6 +319,62 @@ function form_actions() {
     CDEF Item Functions
    -------------------------- */
 
+function duplicate_data_source_profile($source_profile, $title_format) {
+	if (!is_array($source_profile)) {
+		$source_profile = array($source_profile);
+	}
+
+	foreach($source_profile as $id) {
+		$profile = db_fetch_row_prepared('SELECT *
+			FROM data_source_profiles
+			WHERE id = ?',
+			array($id));
+
+		if (cacti_sizeof($profile)) {
+			$save = array();
+
+			$save['id']   = 0;
+
+			foreach($profile as $column => $value) {
+				if ($column == 'id') {
+					continue;
+				} elseif ($column == 'hash') {
+					$save['hash'] = get_hash_data_source_profile(0);
+				} elseif ($column == 'name') {
+					$save['name'] = str_replace('<profile_title>', $value, $title_format);
+				} elseif ($column == 'default') {
+					$save['default'] = '';
+				} else {
+					$save[$column] = $value;
+				}
+			}
+
+			$newid = sql_save($save, 'data_source_profiles');
+
+			if ($newid > 0) {
+				db_execute_prepared("INSERT INTO data_source_profiles_cf
+					SELECT '$newid' AS data_source_profile_id, consolidation_function_id
+					FROM data_source_profiles_cf
+					WHERE data_source_profile_id = ?",
+					array($id));
+
+				db_execute_prepared("INSERT INTO data_source_profiles_rra
+					(`data_source_profile_id`, `name`, `steps`, `rows`, `timespan`)
+					SELECT '$newid', `name`, `steps`, `rows`, `timespan`
+					FROM data_source_profiles_rra
+					WHERE data_source_profile_id = ?",
+					array($id));
+
+				raise_message(1);
+			} else {
+				raise_message(2);
+			}
+		} else {
+			raise_message('profile_error', __('Unable to duplicate Data Source Profile.  Check Cacti Log for errors.'), MESSAGE_LEVEL_ERROR);
+		}
+	}
+}
+
 function profile_item_remove_confirm() {
 	/* ================= input validation ================= */
 	get_filter_request_var('id');
@@ -544,7 +594,7 @@ function profile_edit() {
 			AND local_data_id > 0',
 			array(get_request_var('id')));
 
-		$header_label = __('Data Source Profile [edit: %s]', html_escape($profile['name']) . ($readonly ? ' (Read Only)':''));
+		$header_label = __esc('Data Source Profile [edit: %s]', $profile['name'] . ($readonly ? ' (Read Only)':''));
 	} else {
 		$header_label = __('Data Source Profile [new]');
 		$readonly     = false;
@@ -626,7 +676,7 @@ function profile_edit() {
 		$('body').append("<div id='cdialog'></div>");
 
         $('#consolidation_function_id').multiselect({
-            selectedList: 1,
+            selectedList: 4,
             noneSelectedText: '<?php print __('Select Consolidation Function(s)');?>',
             header: false,
             groupColumns: true,
