@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -77,15 +77,15 @@ if (!isset_request_var('image_format')) {
 
 $graph_data_array['image_format'] = $gtype;
 
-session_write_close();
+cacti_session_close();
 
 /* override: graph start time (unix time) */
-if (!isempty_request_var('graph_start') && get_request_var('graph_start') < 1600000000) {
+if (!isempty_request_var('graph_start') && get_request_var('graph_start') < FILTER_VALIDATE_MAX_DATE_AS_INT) {
 	$graph_data_array['graph_start'] = get_request_var('graph_start');
 }
 
 /* override: graph end time (unix time) */
-if (!isempty_request_var('graph_end') && get_request_var('graph_end') < 1600000000) {
+if (!isempty_request_var('graph_end') && get_request_var('graph_end') < FILTER_VALIDATE_MAX_DATE_AS_INT) {
 	$graph_data_array['graph_end'] = get_request_var('graph_end');
 }
 
@@ -137,6 +137,8 @@ if ($output !== false && $output != '') {
 	ob_end_clean();
 
 	header('Content-type: image/'. $gtype);
+	header('Cache-Control: max-age=15');
+
 	print $output;
 } else {
 	ob_start();
@@ -161,6 +163,7 @@ if ($output !== false && $output != '') {
 	ob_end_clean();
 
 	header('Content-type: image/png');
+	header('Cache-Control: max-age=15');
 
 	if ($image !== false) {
 		print $image;
