@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -121,6 +121,10 @@ $cacti_version_codes = array(
 	'1.2.6'  => '0102',
 	'1.2.7'  => '0102',
 	'1.2.8'  => '0102',
+	'1.2.9'  => '0102',
+	'1.2.10'  => '0102',
+	'1.2.11'  => '0102',
+	'1.2.12'  => '0102'
 );
 
 $messages = array(
@@ -1303,6 +1307,7 @@ $graph_timespans = array(
 	GT_PREV_YEAR      => __('Previous Year')
 );
 
+// ***** MUST BE KEPT IN SYNC WITH graph_timeshifts_vals *********
 $graph_timeshifts = array(
 	GTS_HALF_HOUR => __('%d Min', 30),
 	GTS_1_HOUR    => __('%d Hour', 1),
@@ -1325,6 +1330,29 @@ $graph_timeshifts = array(
 	GTS_2_YEARS   => __('%d Years', 2)
 );
 
+// ***** MUST BE KEPT IN SYNC WITH graph_timeshifts *********
+$graph_timeshifts_vals = array(
+	GTS_HALF_HOUR => sprintf('%d Min', 30),
+	GTS_1_HOUR    => sprintf('%d Hour', 1),
+	GTS_2_HOURS   => sprintf('%d Hours', 2),
+	GTS_4_HOURS   => sprintf('%d Hours', 4),
+	GTS_6_HOURS   => sprintf('%d Hours', 6),
+	GTS_12_HOURS  => sprintf('%d Hours', 12),
+	GTS_1_DAY     => sprintf('%d Day', 1),
+	GTS_2_DAYS    => sprintf('%d Days', 2),
+	GTS_3_DAYS    => sprintf('%d Days', 3),
+	GTS_4_DAYS    => sprintf('%d Days', 4),
+	GTS_1_WEEK    => sprintf('%d Week', 1),
+	GTS_2_WEEKS   => sprintf('%d Weeks', 2),
+	GTS_1_MONTH   => sprintf('%d Month', 1),
+	GTS_2_MONTHS  => sprintf('%d Months', 2),
+	GTS_3_MONTHS  => sprintf('%d Months', 3),
+	GTS_4_MONTHS  => sprintf('%d Months', 4),
+	GTS_6_MONTHS  => sprintf('%d Months', 6),
+	GTS_1_YEAR    => sprintf('%d Year', 1),
+	GTS_2_YEARS   => sprintf('%d Years', 2)
+);
+
 $graph_weekdays = array(
 	WD_SUNDAY    => date('l', strtotime('Sunday')),
 	WD_MONDAY    => date('l', strtotime('Monday')),
@@ -1552,9 +1580,10 @@ $agg_totals_type = array(
 );
 
 $agg_order_types = array(
-	AGGREGATE_ORDER_NONE      => __('No Reordering'),
-	AGGREGATE_ORDER_DS_GRAPH  => __('Data Source, Graph'),
-	AGGREGATE_ORDER_GRAPH_DS  => __('Graph, Data Source'),
+	AGGREGATE_ORDER_NONE       => __('No Reordering'),
+	AGGREGATE_ORDER_DS_GRAPH   => __('Data Source, Graph'),
+	AGGREGATE_ORDER_GRAPH_DS   => __('Graph, Data Source'),
+	AGGREGATE_ORDER_BASE_GRAPH => __('Base Graph Order')
 );
 
 # operators for use with SQL/pattern matching
