@@ -1,6 +1,6 @@
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -194,7 +194,10 @@
 			var $this = image;
 
 			/* load global settings cached in a cookie if available */
-			zoom.custom = unserialize(storage.get(zoom.options.cookieName));
+			if (storage.isSet(zoom.options.cookieName)) {
+				zoom.custom = unserialize(storage.get(zoom.options.cookieName));
+			}
+
 			if (zoom.custom.zoomMode == undefined) zoom.custom.zoomMode = 'quick';
 			if (zoom.custom.zoomOutPositioning == undefined) zoom.custom.zoomOutPositioning = 'center';
 			if (zoom.custom.zoomOutFactor == undefined) zoom.custom.zoomOutFactor = '2';
@@ -729,7 +732,7 @@
 						$('#graph_start').val(newGraphStartTime);
 						$('#graph_end').val(newGraphEndTime);
 
-						initializeGraphs();
+						initializeGraph();
 					}
 				} else {
 					$("input[name='" + zoom.options.submitButton + "']").trigger('click');
@@ -759,7 +762,23 @@
 		}
 
 		function getZoomOutFactorText(zoomOutFactor) {
-			return eval('zoom_i18n_zoom_out + \' (\' + zoom_i18n_zoom_' + zoomOutFactor + ' + \')\'');
+			switch(zoomOutFactor) {
+				case 2:
+					return zoom_i18n_zoom_out + ' (' + zoom_i18n_zoom_2 + ')';
+					break;
+				case 4:
+					return zoom_i18n_zoom_out + ' (' + zoom_i18n_zoom_4 + ')';
+					break;
+				case 8:
+					return zoom_i18n_zoom_out + ' (' + zoom_i18n_zoom_8 + ')';
+					break;
+				case 16:
+					return zoom_i18n_zoom_out + ' (' + zoom_i18n_zoom_16 + ')';
+					break;
+				case 32:
+					return zoom_i18n_zoom_out + ' (' + zoom_i18n_zoom_32 + ')';
+					break;
+			}
 		}
 
 		/*
@@ -839,7 +858,7 @@
 						$('#graph_start').val(newGraphStartTime);
 						$('#graph_end').val(newGraphEndTime);
 
-						initializeGraphs();
+						initializeGraph();
 					}
 				} else {
 					$("input[name='" + zoom.options.submitButton + "']").trigger('click');
