@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -32,10 +32,13 @@
 function nth_percentile($local_data_ids, $start_seconds, $end_seconds, $percentile = 95, $resolution = 0, $peak = false) {
 	$stats = json_decode(rrdtool_function_stats($local_data_ids, $start_seconds, $end_seconds, $percentile, $resolution, $peak), true);
 
-	if ($peak) {
-		return $stats['peak'];
-	} else {
-		return $stats['avg'];
+	$return_val = false;
+	if (!empty($stats)) {
+		if ($peak) {
+			$return_val = $stats['peak'];
+		} else {
+			$return_val = $stats['avg'];
+		}
 	}
 }
 
@@ -150,7 +153,7 @@ function nth_percentile_fetch_statistics($percentile, &$local_data_ids, &$fetch_
 	foreach ($local_data_ids as $ldi => $data_source_name) {
 		if (cacti_sizeof($fetch_array[$ldi]['data_source_names'])) {
 			foreach ($fetch_array[$ldi]['data_source_names'] as $index => $ds_name) {
-				if (cacti_sizeof($fetch_array[$ldi]['values'][$index])) {
+				if (isset($fetch_array[$ldi]['values'][$index]) && cacti_sizeof($fetch_array[$ldi]['values'][$index])) {
 					foreach ($fetch_array[$ldi]['values'][$index] as $timestamp => $data) {
 						if (isset($asum_array[$ds_name]) && isset($asum_array[$ds_name][$timestamp])) {
 							$asum_array[$ds_name][$timestamp] += $data;
@@ -158,6 +161,8 @@ function nth_percentile_fetch_statistics($percentile, &$local_data_ids, &$fetch_
 							$asum_array[$ds_name][$timestamp]  = $data;
 						}
 					}
+				} else {
+					return false;
 				}
 			}
 		}
