@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -144,7 +144,7 @@ function html_start_box($title, $width, $div, $cell_padding, $align, $add_text,
 function html_end_box($trailing_br = true, $div = false) {
 	if ($div) {
 		print '</div></div>';
-	}else {
+	} else {
 		print '</table></div>';
 	}
 
@@ -474,11 +474,12 @@ function graph_drilldown_icons($local_graph_id, $type = 'graph_buttons') {
    @arg $total_rows - the total number of rows in the navigation system
    @arg $object - the object types that is being displayed
    @arg $page_var - the object types that is being displayed
-   @arg $return_to - paint the resulting page into this dom object */
-function html_nav_bar($base_url, $max_pages, $current_page, $rows_per_page, $total_rows, $colspan=30, $object = '', $page_var = 'page', $return_to = '') {
+   @arg $return_to - paint the resulting page into this dom object
+   @arg $page_count - provide a page count */
+function html_nav_bar($base_url, $max_pages, $current_page, $rows_per_page, $total_rows, $colspan=30, $object = '', $page_var = 'page', $return_to = '', $page_count = true) {
 	if ($object == '') $object = __('Rows');
 
-	if ($total_rows > $rows_per_page) {
+	if ($total_rows > $rows_per_page && $page_count) {
 		if (substr_count($base_url, '?') == 0) {
 			$base_url = trim($base_url) . '?';
 		} else {
@@ -499,11 +500,41 @@ function html_nav_bar($base_url, $max_pages, $current_page, $rows_per_page, $tot
 			</div>
 		</div>";
 	} elseif ($total_rows > 0) {
-		$nav = "<div class='navBarNavigation'>
-			<div class='navBarNavigationNone'>
-				" . __('All %d %s', $total_rows, $object) . '
-			</div>
-		</div>';
+		if ($page_count || ($total_rows < $rows_per_page && $current_page ==1) ) {
+			$nav = "<div class='navBarNavigation'>
+				<div class='navBarNavigationNone'>
+					" . __('All %d %s', $total_rows, $object) . "
+				</div>
+			</div>\n";
+		} else {
+			if (substr_count($base_url, '?') == 0) {
+				$base_url = trim($base_url) . '?';
+			} else {
+				$base_url = trim($base_url) . '&';
+			}
+
+			$url_page_select = "<ul class='pagination'>"; //for the same height as write in get_page_list()
+			$url_page_select .= "<li>$current_page</a></li>";
+			$url_page_select .= '</ul>';
+
+			$nav = "<div class='navBarNavigation'>
+				<div class='navBarNavigationPrevious'>
+					" . (($current_page > 1) ? "<a href='#' onClick='goto$page_var(" . ($current_page-1) . ");return false;'><i class='fa fa-angle-double-left previous'></i>" . __('Previous'). "</a>":"") . "
+				</div>
+				<div class='navBarNavigationCenter'>
+					" . __('Current Page: %s', $url_page_select) . "
+				</div>
+				<div class='navBarNavigationNext'>
+					" . ($total_rows >= $rows_per_page ? "<a href='#' onClick='goto$page_var(" . ($current_page+1) . ");return false;'>" . __('Next'). "<i class='fa fa-angle-double-right next'></i></a>":"") . "
+				</div>
+			</div>\n";
+
+			if ($return_to != '') {//code as in get_page_list()
+				$nav .= "<script type='text/javascript'>function goto$page_var(pageNo) { if (typeof url_graph === 'function') { var url_add=url_graph('') } else { var url_add=''; }; $.get('" . $base_url . "header=false&" . $page_var . "='+pageNo+url_add).done(function(data) { $('#$return_to').html(data); applySkin(); }); }</script>";
+			} else {
+				$nav .= "<script type='text/javascript'>function goto${page_var}(pageNo) { if (typeof url_graph === 'function') { var url_add=url_graph('') } else { var url_add=''; }; document.location='$base_url$page_var='+pageNo+url_add }</script>";
+			}
+		}
 	} else {
 		$nav = "<div class='navBarNavigation'>
 			<div class='navBarNavigationNone'>
@@ -1100,10 +1131,10 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 				$matrix_title = 'TEXTALIGN: ' . ucfirst($item['textalign']);
 				break;
 			case preg_match('/(TICK)/', $_graph_type_name):
-				$matrix_title = '(' . $item['data_source_name'] . '): ' . $item['text_format'];
+				$matrix_title = $item['data_source_name'] . ': ' . $item['text_format'];
 				break;
 			case preg_match('/(AREA|STACK|GPRINT|LINE[123])/', $_graph_type_name):
-				$matrix_title = '(' . $item['data_source_name'] . '): ' . $item['text_format'];
+				$matrix_title = $item['data_source_name'] . ': ' . $item['text_format'];
 				break;
 			case preg_match('/(HRULE)/', $_graph_type_name):
 				$matrix_title = 'HRULE: ' . $item['value'];
@@ -1191,10 +1222,29 @@ function is_menu_pick_active($menu_url) {
 		} else {
 			return false;
 		}
-	}
-
-	/* break out the URL and variables */
-	if (!is_array($url_array) || (is_array($url_array) && !cacti_sizeof($url_array))) {
+	} elseif (strpos($_SERVER['REQUEST_URI'], 'graph_templates_items.php') !== false) {
+		/* special case for Graph Template items edit */
+		if (strpos($menu_url, 'graph_templates.php') !== false) {
+			return true;
+		} else {
+			return false;
+		}
+	} elseif (strpos($_SERVER['REQUEST_URI'], 'graph_items.php') !== false) {
+		/* special case for Graph items edit */
+		if (strpos($menu_url, 'graphs.php') !== false) {
+			return true;
+		} else {
+			return false;
+		}
+	} elseif (strpos($_SERVER['REQUEST_URI'], 'color_templates_items.php') !== false) {
+		/* special case for Color Templates items edit */
+		if (strpos($menu_url, 'color_templates.php') !== false) {
+			return true;
+		} else {
+			return false;
+		}
+	} elseif (!is_array($url_array) || (is_array($url_array) && !cacti_sizeof($url_array))) {
+		/* break out the URL and variables */
 		$url_array = parse_url($_SERVER['REQUEST_URI']);
 		if (isset($url_array['query'])) {
 			parse_str($url_array['query'], $url_parts);
@@ -1203,6 +1253,11 @@ function is_menu_pick_active($menu_url) {
 		}
 	}
 
+	// Host requires another check
+	if (strpos($menu_url, 'host.php?action=edit&create=true') !== false) {
+		return false;
+	}
+
 	$menu_array = parse_url($menu_url);
 	if ($menu_array === false) {
 		return false;
@@ -1247,7 +1302,7 @@ function draw_menu($user_menu = '') {
 		$user_menu = $menu;
 	}
 
-	print "<tr><td><table><tr><td><div id='menu'><ul id='nav' role='menu'>";
+	print "<tr><td><table width='100%'><tr><td><div id='menu'><ul id='nav' role='menu'>";
 
 	/* loop through each header */
 	$i = 0;
@@ -1325,14 +1380,14 @@ function draw_menu($user_menu = '') {
 									print "<li><a role='menuitem' class='pic selected' href='";
 									print html_escape($item_sub_url) . "'";
 									if ($item_sub_external) {
-										print " target='_blank'";
+										print " target='_blank' rel='noopener'";
 									}
 									print ">$item_sub_title</a></li>";
 								} else {
 									print "<li><a role='menuitem' class='pic' href='";
 									print html_escape($item_sub_url) . "'";
 									if ($item_sub_external) {
-										print " target='_blank'";
+										print " target='_blank' rel='noopener'";
 									}
 									print ">$item_sub_title</a></li>";
 								}
@@ -1355,14 +1410,14 @@ function draw_menu($user_menu = '') {
 							print "<li><a role='menuitem' class='pic selected' href='";
 							print html_escape($item_url) . "'";
 							if ($item_external) {
-								print " target='_blank'";
+								print " target='_blank' rel='noopener'";
 							}
 							print ">$item_title</a></li>";
 						} else {
 							print "<li><a role='menuitem' class='pic' href='";
 							print html_escape($item_url) . "'";
 							if ($item_external) {
-								print " target='_blank'";
+								print " target='_blank' rel='noopener'";
 							}
 							print ">$item_title</a></li>";
 						}
@@ -1399,7 +1454,7 @@ function draw_actions_dropdown($actions_array, $delete_action = 1) {
 	?>
 	<div class='actionsDropdown'>
 		<div>
-			<span class='actionsDropdownArrow'><img src='<?php echo $config['url_path']; ?>images/arrow.gif' alt=''></span>
+			<span class='actionsDropdownArrow'><img src='<?php print $config['url_path']; ?>images/arrow.gif' alt=''></span>
 			<?php form_dropdown('drp_action', $actions_array, '', '', '0', '', '');?>
 			<span class='actionsDropdownButton'><input type='submit' class='ui-button ui-corner-all ui-widget' id='submit' value='<?php print __esc('Go');?>' title='<?php print __esc('Execute Action');?>'></span>
 		</div>
@@ -1553,7 +1608,7 @@ function html_show_tabs_left() {
 
 	if (get_selected_theme() == 'classic') {
 		if ($show_console_tab == true) {
-			?><a id='tab-console' <?php print (is_console_page(get_current_page()) ? " class='selected'":'');?> href='<?php echo $config['url_path']; ?>index.php'><img src='<?php echo $config['url_path']; ?>images/tab_console<?php print (is_console_page(get_current_page()) ? '_down':'');?>.gif' alt='<?php print __('Console');?>'></a><?php
+			?><a id='tab-console' <?php print (is_console_page(get_current_page()) ? " class='selected'":'');?> href='<?php print $config['url_path']; ?>index.php'><img src='<?php echo $config['url_path']; ?>images/tab_console<?php print (is_console_page(get_current_page()) ? '_down':'');?>.gif' alt='<?php print __('Console');?>'></a><?php
 		}
 
 		if ($realm_allowed[7]) {
@@ -1789,10 +1844,10 @@ function html_show_tabs_left() {
 				$i++;
 			}
 
-			print "<li><a id='$id' class='lefttab" . (isset($tab['selected']) ? ' selected':'') . "' href='" . html_escape($tab['url']) . "'><span class='fa glyph_$id'></span><span class='text_$id'>" . html_escape($tab['title']) . "</span></a><a id='menu-$id' class='maintabs-submenu' href='#'><i class='fa fa-angle-down'></i></a></li>";
+			print "<li><a id='$id' role='tab' class='lefttab" . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . html_escape($tab['url']) . "'><span class='fa glyph_$id'></span><span class='text_$id'>" . html_escape($tab['title']) . "</span></a><a id='menu-$id' class='maintabs-submenu' href='#'><i class='fa fa-angle-down'></i></a></li>";
 		}
 
-		print "<li class='ellipsis maintabs-submenu-ellipsis'><a id='menu-ellipsis' class='submenu-ellipsis' href='#'><i class='fa fa-angle-down'></i></a></li>";
+		print "<li class='ellipsis maintabs-submenu-ellipsis'><a id='menu-ellipsis' role='tab' aria-selected='false' class='submenu-ellipsis' href='#'><i class='fa fa-angle-down'></i></a></li>";
 
 		print '</ul></nav></div>';
 	}
@@ -1805,21 +1860,21 @@ function html_graph_tabs_right() {
 
 	if ($theme == 'classic') {
 		if (is_view_allowed('show_tree')) {
-			?><a class='righttab' id='treeview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=tree');?>'><img src='<?php echo $config['url_path']; ?>images/tab_mode_tree<?php
+			?><a class='righttab' id='treeview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=tree');?>'><img src='<?php print $config['url_path']; ?>images/tab_mode_tree<?php
 			if (isset_request_var('action') && get_nfilter_request_var('action') == 'tree') {
 				print '_down';
 			}?>.gif' title='<?php print __esc('Tree View');?>' alt=''></a><?php
 		}?><?php
 
 		if (is_view_allowed('show_list')) {
-			?><a class='righttab' id='listview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=list');?>'><img src='<?php echo $config['url_path']; ?>images/tab_mode_list<?php
+			?><a class='righttab' id='listview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=list');?>'><img src='<?php print $config['url_path']; ?>images/tab_mode_list<?php
 			if (isset_request_var('action') && get_nfilter_request_var('action') == 'list') {
 				print '_down';
 			}?>.gif' title='<?php print __esc('List View');?>' alt=''></a><?php
 		}?><?php
 
 		if (is_view_allowed('show_preview')) {
-			?><a class='righttab' id='preview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=preview');?>'><img src='<?php echo $config['url_path']; ?>images/tab_mode_preview<?php
+			?><a class='righttab' id='preview' href='<?php print html_escape($config['url_path'] . 'graph_view.php?action=preview');?>'><img src='<?php print $config['url_path']; ?>images/tab_mode_preview<?php
 			if (isset_request_var('action') && get_nfilter_request_var('action') == 'preview') {
 				print '_down';
 			}?>.gif' title='<?php print __esc('Preview View');?>' alt=''></a><?php
@@ -1881,24 +1936,24 @@ function html_graph_tabs_right() {
 			switch($tab['id']) {
 			case 'tree':
 				if (isset($tab['image']) && $tab['image'] != '') {
-					print "<li role='tab'><a id='treeview' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
+					print "<li><a id='treeview' role='tab' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
 				} else {
-					print "<li role='tab'><a title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
+					print "<li><a role='tab' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
 				}
 				break;
 			case 'list':
 				if (isset($tab['image']) && $tab['image'] != '') {
-					print "<li role='tab'><a id='listview' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
+					print "<li><a id='listview' role='tab' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
 				} else {
-					print "<li role='tab'><a title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
+					print "<li><a role='tab' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
 				}
 
 				break;
 			case 'preview':
 				if (isset($tab['image']) && $tab['image'] != '') {
-					print "<li role='tab'><a id='preview' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
+					print "<li><a role='tab' id='preview' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'><img src='" . $config['url_path'] . $tab['image'] . "' alt='' style='vertical-align:bottom;'></a></li>";
 				} else {
-					print "<li role='tab'><a title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? 'selected':'') . "' href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
+					print "<li><a role='tab' title='" . html_escape($tab['title']) . "' class='righttab " . (isset($tab['selected']) ? " selected' aria-selected='true'":"' aria-selected='false'") . " href='" . $tab['url'] . "'>" . $tab['title'] . '</a></li>';
 				}
 
 				break;
@@ -2291,13 +2346,25 @@ function html_common_header($title, $selectedTheme = '') {
 		$selectedTheme = get_selected_theme();
 	}
 
+	if ($selectedTheme == 'classic') {
+		print "<meta content='width=device-width, initial-scale=0.5, minimum-scale=0.2, maximum-scale=5' name='viewport'>" . PHP_EOL;
+	} else {
+		print "<meta content='width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=5' name='viewport'>" . PHP_EOL;
+	}
+
+	$script_policy = read_config_option('content_security_policy_script');
+	if ($script_policy != '0' && $script_policy != '') {
+		$script_policy = "'$script_policy'";
+	}
+
 	?>
 	<meta http-equiv='X-UA-Compatible' content='IE=Edge,chrome=1'>
-	<meta content='width=device-width, initial-scale=1.0, minimum-scale=1.0, maximum-scale=1.0' name='viewport'>
 	<meta name='apple-mobile-web-app-capable' content='yes'>
+	<meta name='description' content='Monitoring tool of the Internet'>
 	<meta name='mobile-web-app-capable' content='yes'>
+	<meta http-equiv="Content-Security-Policy" content="default-src *; img-src 'self' data: blob:; style-src 'self' 'unsafe-inline'; script-src 'self' <?php print $script_policy;?> 'unsafe-inline'; worker-src 'self'">
 	<meta name='robots' content='noindex,nofollow'>
-	<title><?php echo $title; ?></title>
+	<title><?php print $title; ?></title>
 	<meta http-equiv='Content-Type' content='text/html;charset=utf-8'>
 	<script type='text/javascript'>
 		var theme='<?php print $selectedTheme;?>';
@@ -2381,8 +2448,8 @@ function html_common_header($title, $selectedTheme = '') {
 		var zoom_i18n_settings='<?php print __esc('Settings');?>';
 		var zoom_i18n_3rd_button='<?php print __esc('3rd Mouse Button');?>';
 	</script>
-	<link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/images/favicon.ico' rel='shortcut icon'>
-	<link href='<?php echo $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/images/cacti_logo.gif' rel='icon' sizes='96x96'>
+	<link href='<?php print $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/images/favicon.ico' rel='shortcut icon'>
+	<link href='<?php print $config['url_path']; ?>include/themes/<?php print $selectedTheme;?>/images/cacti_logo.gif' rel='icon' sizes='96x96'>
 	<?php
 	print get_md5_include_css('include/themes/' . $selectedTheme .'/jquery.zoom.css');
 	print get_md5_include_css('include/themes/' . $selectedTheme .'/jquery-ui.css');
@@ -2396,32 +2463,31 @@ function html_common_header($title, $selectedTheme = '') {
 	print get_md5_include_css('include/fa/css/fontawesome.css');
 	print get_md5_include_css('include/vendor/flag-icon-css/css/flag-icon.css');
 	print get_md5_include_css('include/themes/' . $selectedTheme .'/main.css');
-	print get_md5_include_js('include/js/screenfull.js');
+	print get_md5_include_js('include/js/screenfull.js', true);
 	print get_md5_include_js('include/js/jquery.js');
 	print get_md5_include_js('include/js/jquery-ui.js');
-	print get_md5_include_js('include/js/jquery.ui.touch.punch.js');
-	print get_md5_include_js('include/js/jquery.cookie.js');
+	print get_md5_include_js('include/js/jquery.ui.touch.punch.js', true);
+	print get_md5_include_js('include/js/jquery.cookie.js', true);
 	print get_md5_include_js('include/js/js.storage.js');
 	print get_md5_include_js('include/js/jstree.js');
-	print get_md5_include_js('include/js/jquery.hotkeys.js');
-	print get_md5_include_js('include/js/jquery.tablednd.js');
-	print get_md5_include_js('include/js/jquery.zoom.js');
+	print get_md5_include_js('include/js/jquery.hotkeys.js', true);
+	print get_md5_include_js('include/js/jquery.tablednd.js', true);
+	print get_md5_include_js('include/js/jquery.zoom.js', true);
 	print get_md5_include_js('include/js/jquery.multiselect.js');
 	print get_md5_include_js('include/js/jquery.multiselect.filter.js');
-	print get_md5_include_js('include/js/jquery.timepicker.js');
-	print get_md5_include_js('include/js/jquery.colorpicker.js');
+	print get_md5_include_js('include/js/jquery.timepicker.js', true);
+	print get_md5_include_js('include/js/jquery.colorpicker.js', true);
 	print get_md5_include_js('include/js/jquery.tablesorter.js');
-	print get_md5_include_js('include/js/jquery.tablesorter.widgets.js');
-	print get_md5_include_js('include/js/jquery.tablesorter.pager.js');
-	print get_md5_include_js('include/js/jquery.metadata.js');
-	print get_md5_include_js('include/js/jquery.sparkline.js');
-	print get_md5_include_js('include/js/Chart.js');
-	print get_md5_include_js('include/js/dygraph-combined.js');
-	print get_md5_include_js('include/js/d3.js');
-	print get_md5_include_js('include/js/c3.js');
+	print get_md5_include_js('include/js/jquery.tablesorter.widgets.js', true);
+	print get_md5_include_js('include/js/jquery.tablesorter.pager.js', true);
+	print get_md5_include_js('include/js/jquery.sparkline.js', true);
+	print get_md5_include_js('include/js/Chart.js', true);
+	print get_md5_include_js('include/js/dygraph-combined.js', true);
+	print get_md5_include_js('include/js/d3.js', true);
+	print get_md5_include_js('include/js/c3.js', true);
 	print get_md5_include_js('include/layout.js');
 	print get_md5_include_js('include/js/pace.js');
-	print get_md5_include_js('include/realtime.js');
+	print get_md5_include_js('include/realtime.js', true);
 	print get_md5_include_js('include/themes/' . $selectedTheme .'/main.js');
 
 	if (isset($path2calendar) && file_exists($path2calendar)) {
