@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -265,7 +265,7 @@ function utime_add($timestamp, $yr=0, $mon=0, $day=0, $hr=0, $min=0, $sec=0) {
  @param string $string 	- the string to append to the log file
  @param bool $output 	- whether to output the log line to the browser using pring() or not
  @param string $environ - tell's from where the script was called from */
-function reports_log($string, $output = false, $environ='REPORTS', $level=POLLER_VERBOSITY_NONE) {
+function reports_log($string, $output = false, $environ = 'REPORTS', $level = POLLER_VERBOSITY_NONE) {
 	# Define REPORTS_DEBUG if not already set
 	if (!defined('REPORTS_DEBUG')) {
 		if (function_exists('read_config_option')) {
@@ -276,7 +276,7 @@ function reports_log($string, $output = false, $environ='REPORTS', $level=POLLER
 	}
 
 	# if current verbosity >= level of current message, print it
-	if (strstr($string, 'STATS')) {
+	if (strpos($string, 'STATS') !== false) {
 		cacti_log($string, $output, 'SYSTEM');
 	} elseif (REPORTS_DEBUG >= $level) {
 		cacti_log($string, $output, $environ);
@@ -482,14 +482,14 @@ function generate_report($report, $force = false) {
 
 	if ($error != '') {
 		if (isset_request_var('id')) {
-			raise_message(__('Problems sending Report \'%s\' Problem with e-mail Subsystem Error is \'%s\'', $report['name'], $error), MESSAGE_LEVEL_ERROR);
+			raise_message('report_message', __('Problems sending Report \'%s\' Problem with e-mail Subsystem Error is \'%s\'', $report['name'], $error), MESSAGE_LEVEL_ERROR);
 		} else {
 			reports_log(__FUNCTION__ . ", Problems sending Report '" . $report['name'] . "'.  Problem with e-mail Subsystem Error is '$error'", false, 'REPORTS', POLLER_VERBOSITY_LOW);
 		}
 
 		return false;
 	} elseif (isset($_REQUEST)) {
-		raise_message(__('Report \'%s\' Sent Successfully', $report['name']), MESSAGE_LEVEL_INFO);
+		raise_message('report_message', __('Report \'%s\' Sent Successfully', $report['name']), MESSAGE_LEVEL_INFO);
 
 		$int = read_config_option('poller_interval');
 
@@ -704,7 +704,7 @@ function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$t
 			$outstr .= "\t\t\t<td class='title' style='text-align:" . $alignment[$report['alignment']] . ";font-size:" . $report['font_size'] . "pt;'>" . PHP_EOL;
 		}
 
-		$outstr .= "\t\t\t\t" . $report['name'] . PHP_EOL;
+		$outstr .= "\t\t\t\t" . html_escape($report['name']) . PHP_EOL;
 		$outstr .= "\t\t\t</td>" . PHP_EOL;
 		$outstr .= "\t\t</tr>" . PHP_EOL;
 		# this function should be called only at the appropriate targeted time when in batch mode
@@ -1498,7 +1498,7 @@ function reports_get_format_files() {
 /**
  * define the reports code that will be processed at the end of each polling event
  */
-function reports_poller_bottom () {
+function reports_poller_bottom() {
 	global $config;
 	include_once($config['base_path'] . '/lib/poller.php');
 
@@ -1642,7 +1642,7 @@ function reports_graphs_action_execute($action) {
 		}
 
 		if ($message != '') {
-			raise_message($message, MESSAGE_LEVEL_INFO);
+			raise_message('report_send', $message, MESSAGE_LEVEL_INFO);
 		}
 	} else {
 		return $action;
