@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -62,7 +62,7 @@ function sig_handler($signo) {
         case SIGINT:
 			if ($thread > 0) {
 				clearTask($network_id, getmypid());
-				exit;
+				exit(0);
 			} elseif($thread == 0 && !$master) {
 				$pids = array_rekey(db_fetch_assoc_prepared("SELECT pid
 					FROM automation_processes
@@ -100,7 +100,7 @@ function sig_handler($signo) {
 				clearTask($network_id, getmypid());
 			}
 
-            exit;
+            exit(0);
 
             break;
         default:
@@ -167,15 +167,15 @@ if (cacti_sizeof($parms)) {
 			case '-v':
 			case '--version':
 				display_version();
-				exit;
+				exit(0);
 			case '-h':
 			case '--help':
 				display_help();
-				exit;
+				exit(0);
 			default:
 				print 'ERROR: Invalid Parameter ' . $parameter . "\n\n";
 				display_help();
-				exit;
+				exit(1);
 		}
 	}
 }
@@ -189,7 +189,7 @@ if (function_exists('pcntl_signal')) {
 // Let's ensure that we were called correctly
 if (!$master && !$network_id) {
 	print "FATAL: You must specify -M to Start the Master Control Process, or the Network ID using --network\n";
-	exit;
+	exit(1);
 }
 
 // Simple check for a disabled network
@@ -202,11 +202,15 @@ if (!$master && $thread == 0) {
 
 	if ($status != 'on' && !$force) {
 		cacti_log(automation_get_pid() . " WARNING: The Network ID: $network_id is disabled.  You must use the 'force' option to force it's execution.", true, 'AUTOM8');
-		exit;
+		exit(1);
 	}
 }
 
 if ($master) {
+	if (!db_table_exists('automation_networks')) {
+		exit(0);
+	}
+
 	$networks = db_fetch_assoc_prepared('SELECT *
 		FROM automation_networks
 		WHERE poller_id = ?',
@@ -225,7 +229,7 @@ if ($master) {
 		}
 	}
 
-	exit;
+	exit(0);
 }
 
 // Check for Network Master
@@ -342,7 +346,7 @@ if (!$master && $thread == 0) {
 			clearAllTasks($network_id);
 			reportNetworkStatus($network_id, $preexisting_devices);
 
-			exit;
+			exit(0);
 		} else {
 			$failcount++;
 		}
@@ -355,7 +359,7 @@ if (!$master && $thread == 0) {
 	endTask($network_id, getmypid());
 }
 
-exit;
+exit(0);
 
 function discoverDevices($network_id, $thread) {
 	$network = db_fetch_row_prepared('SELECT *
@@ -390,7 +394,7 @@ function discoverDevices($network_id, $thread) {
 		if ($command == 'cancel' || empty($command)) {
 			removeMyProcess(getmypid(), $network_id);
 			killProcess(getmypid());
-			exit;
+			exit(0);
 		}
 
 		// set and ip to be scanned
@@ -492,7 +496,7 @@ function discoverDevices($network_id, $thread) {
 				}
 			}
 
-			$exists = db_fetch_row_prepared('SELECT id, snmp_version, status
+			$exists = db_fetch_row_prepared('SELECT id, snmp_version, status, deleted
 				FROM host
 				WHERE hostname IN (?,?)',
 				array($device['ip_address'], $device['hostname']));
@@ -581,25 +585,29 @@ function discoverDevices($network_id, $thread) {
 							$snmp_sysName_short = $snmp_sysName;
 						}
 
-						$exists = db_fetch_row_prepared('SELECT id, status, snmp_version
+						$exists = db_fetch_row_prepared('SELECT id, status, snmp_version, deleted
 							FROM host
 							WHERE hostname IN (?,?)',
 							array($snmp_sysName_short, $snmp_sysName));
 
 						if (cacti_sizeof($exists)) {
-							if ($exists['status'] == 3 || $exists['status'] == 2) {
-								addUpDevice($network_id, getmypid());
+							if ($exists['deleted'] != 'on') {
+								if ($exists['status'] == 3 || $exists['status'] == 2) {
+									addUpDevice($network_id, getmypid());
 
-								if ($exists['snmp_version'] > 0) {
-									addSNMPDevice($network_id, getmypid());
+									if ($exists['snmp_version'] > 0) {
+										addSNMPDevice($network_id, getmypid());
+									}
+
+									// Rerun data queries if specified
+									rerunDataQueries($exists['id'], $network);
 								}
 
-								// Rerun data queries if specified
-								rerunDataQueries($exists['id'], $network);
+								automation_debug(' Device is in Cacti!');
+							} else {
+								automation_debug(' Device is in Cacti but marked as deleted!');
 							}
 
-							automation_debug(' Device is in Cacti!');
-
 							markIPDone($device['ip_address'], $network_id);
 						} else {
 							$host_id = 0;
@@ -779,18 +787,23 @@ function discoverDevices($network_id, $thread) {
 					markIPDone($device['ip_address'], $network_id);
 				}
 			} else {
-				if ($exists['status'] == 3 || $exists['status'] == 2) {
-					addUpDevice($network_id, getmypid());
+				if ($exists['deleted'] != 'on') {
+					if ($exists['status'] == 3 || $exists['status'] == 2) {
+						addUpDevice($network_id, getmypid());
 
-					if ($exists['snmp_version'] > 0) {
-						addSNMPDevice($network_id, getmypid());
+						if ($exists['snmp_version'] > 0) {
+							addSNMPDevice($network_id, getmypid());
+						}
+
+						// Rerun data queries if specified
+						rerunDataQueries($exists['id'], $network);
 					}
 
-					// Rerun data queries if specified
-					rerunDataQueries($exists['id'], $network);
+					automation_debug(", Status: Already in Cacti\n");
+				} else {
+					automation_debug(", Status: Already in Cacti but marked as deleted\n");
 				}
 
-				automation_debug(", Status: Already in Cacti\n");
 				markIPDone($device['ip_address'], $network_id);
 			}
 		} else {
