@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2019 The Cacti Group                                 |
+ | Copyright (C) 2004-2020 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -97,6 +97,11 @@ switch (get_request_var('action')) {
 		snmpagent_utilities_run_cache();
 		bottom_footer();
 		break;
+	case 'purge_data_source_statistics';
+		purge_data_source_statistics();
+		raise_message('purge_dss', __('Data Source Statistics Purged.'), MESSAGE_LEVEL_INFO);
+		header('Location: utilities.php');
+		break;
 	case 'rebuild_snmpagent_cache';
 		snmpagent_cache_rebuilt();
 		header('Location: utilities.php?action=view_snmpagent_cache');exit;
@@ -222,7 +227,7 @@ function utilities_view_tech($php_info = '') {
 	load_current_session_value('tab', 'sess_ts_tabs', 'summary');
 	$current_tab = get_nfilter_request_var('tab');
 
-	$header_label = __('Technical Support [%s]', $tabs[get_request_var('tab')]);
+	$header_label = __esc('Technical Support [%s]', $tabs[get_request_var('tab')]);
 
 	if (cacti_sizeof($tabs)) {
 		$i = 0;
@@ -457,7 +462,7 @@ function utilities_view_tech($php_info = '') {
 		print "<td>" . __('PHP SNMP') . "</td>\n";
 		print '<td>';
 		if (function_exists('snmpget')) {
-			print __('Installed');
+			print __('Installed. <span class="deviceDown">Note: If you are planning on using SNMPv3, you must remove php-snmp and use the Net-SNMP toolset.</span>');
 		} else {
 			print __('Not Installed');
 		}
@@ -1918,6 +1923,13 @@ function utilities() {
 		),
 	);
 
+	$utilities[__('Data Source Statistics Utilities')] = array(
+		__('Purge Data Source Statistics') => array(
+			'link'  => 'utilities.php?action=purge_data_source_statistics',
+			'description' => __('This menu pick will purge all existing Data Source Statistics from the Database.  If Data Source Statistics is enabled, the Data Sources Statistics will start collection again on the next Data Collector pass.')
+		),
+	);
+
 	$utilities[__('RRD Utilities')] = array(
 		__('RRDfile Cleaner') => array(
 			'link'  => 'rrdcleaner.php',
@@ -1969,6 +1981,22 @@ function utilities() {
 	html_end_box();
 }
 
+function purge_data_source_statistics() {
+	$tables = array(
+		'data_source_stats_daily',
+		'data_source_stats_hourly',
+		'data_source_stats_hourly_cache',
+		'data_source_stats_hourly_last',
+		'data_source_stats_monthly',
+		'data_source_stats_weekly',
+		'data_source_stats_yearly'
+	);
+
+	foreach($tables as $table) {
+		db_execute('TRUNCATE TABLE ' . $table);
+	}
+}
+
 function boost_display_run_status() {
 	global $config, $refresh_interval, $boost_utilities_interval, $boost_refresh_interval, $boost_max_runtime;
 
